#!/bin/bash

# This script populates partitions for a RAW hard drive image
# mounted as /dev/loop0
# Default Layout: 
## /dev/loop0 => whole device
## /dev/loop1 => /boot
## /dev/loop2 => /
## /dev/loop3 => swap

. /usr/lib/mdvvhdprov/common.sh

DEVICE=/dev/${MAIN_LOOP}
ROOT_SIZE=$1
ROOT_UP=$((${ROOT_SIZE} - 256))
SWAP_DOWN=$((${ROOT_UP} + 1))
SWAP_UP=$((${SWAP_DOWN} + 255))
PART_BOOT_SIZE="1 33"
PART_ROOT_SIZE="34 ${ROOT_UP}"
PART_SWAP_SIZE="${SWAP_DOWN} ${SWAP_UP}"

echo "Creating partition table on ${DEVICE}..."
parted -s ${DEVICE} mklabel msdos
if [ $? -ne 0 ]
then
	echo " Failed"
	exit 1
fi
sync

for PART in BOOT ROOT SWAP; do
	S=PART_${PART}_SIZE
	echo "Creating partition '${PART}' on ${DEVICE} size: ${!S}..."
	parted -s ${DEVICE} mkpart primary ${!S}
	sync

	if [ $? -ne 0 ]
	then
		echo " Failed"
		exit 1
	fi

	echo " Done."
done;
exit 0
